@@ -1,15 +1,12 @@
 ##################################################################################
 #
-# ddrlib - Collection of functions used in DDR-Python scripts
+# ddrlib - Collection of functions used in DDR-Python scripts for NX-OS
 #
-# ddrlib functions interact with device management interfaces including
-# NETCONF, ssh, cli, NETCONF RFC5277 notificaitons.
+# ddrlib functions interact with device management interfaces including cli
 # Scripts using ddrlib functions can perform multiple operations including:
 #
 #    * Triggering execution when specific Syslog messages are generated
 #    * Triggering execution by executing show commands, extracting parameters and triggering on values
-#    * Triggering execution by executing NETCONF get requests, extract parameters and trigger on values
-#    * Execute NETCONF get operation for operational or configuration data and return data
 #    * Generate a Syslog message with content passed to the function
 #    * Execute a CLI command on the device in exec mode and optionally return the results
 #    * Delay execution for a specified number of seconds
@@ -24,8 +21,6 @@ import re
 import time
 import datetime
 from datetime import datetime
-from ncclient import manager
-from ncclient.xml_ import to_ele
 from lxml import etree
 import xml.dom.minidom
 import xml.etree.ElementTree as ET
@@ -35,7 +30,7 @@ import os
 import operator
 from ddrlib import *
 import genie_parsers
-# if running in device Guestshell import python CLI packate
+# if running in device Guestshell import python CLI package
 try:
     import cli
 except: pass
